'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

exports.default = function () {
    // connect to "background" store
    var connection = chrome.runtime.connect({ name: _constants.CONNECTION_NAME });

    // listen for changes in the "background" store
    connection.onMessage.addListener(handleMessage);

    // return promise to allow getting current state of "background" store
    return new Promise(function (resolve) {
        chrome.runtime.sendMessage({ type: _constants.UPDATE_STATE }, function (res) {
            state = res;

            // return an object with equivalent to Redux store interface
            resolve({
                subscribe: subscribe,
                dispatch: dispatch,
                getState: getState
            });
        });
    });
};

var _constants = require('./constants');

var listeners = [];

var state = void 0;

function handleMessage(msg) {
    if (msg.type === _constants.UPDATE_STATE) {
        state = msg.data;

        listeners.forEach(function (l) {
            return l();
        });
    }
}

function subscribe(listener) {
    listeners.push(listener);

    // return unsubscribe function
    return function () {
        listeners = listeners.filter(function (l) {
            return l !== listener;
        });
    };
}

function dispatch(action) {
    // perform an action to change state of "background" store
    chrome.runtime.sendMessage({
        type: _constants.DISPATCH,
        action: action
    });
}

function getState() {
    return state;
}